<nav>
  <a href="{{ root_page.url }}">{{ root_page.title }}</a>
  {% for page in menu_pages %}
    <a href="{{ page.url }}">
      {{ page.title }}{% if not page.live %} (not live){% endif %}
    </a>
  {% endfor %}
</nav>
